package com.phm.manage.service;

import com.phm.manage.domain.Fleet;

import java.util.List;

/**
 * 机队信息Service接口
 *
 * @author phm
 * @date 2023-08-22
 */
public interface IFleetService {
    /**
     * 查询机队信息
     *
     * @param id 机队信息主键
     * @return 机队信息
     */
    public Fleet selectFleetById(Long id);

    /**
     * 查询机队信息列表
     *
     * @param fleet 机队信息
     * @return 机队信息集合
     */
    public List<Fleet> selectFleetList(Fleet fleet);

    /**
     * 新增机队信息
     *
     * @param fleet 机队信息
     * @return 结果
     */
    public int insertFleet(Fleet fleet);

    /**
     * 修改机队信息
     *
     * @param fleet 机队信息
     * @return 结果
     */
    public int updateFleet(Fleet fleet);

    /**
     * 批量删除机队信息
     *
     * @param ids 需要删除的机队信息主键集合
     * @return 结果
     */
    public int deleteFleetByIds(Long[] ids);

    /**
     * 删除机队信息信息
     *
     * @param id 机队信息主键
     * @return 结果
     */
    public int deleteFleetById(Long id);
}
